@@ -1,5 +1,7 @@
-cm2 <-
-function(rtot=NULL,ctot=NULL,m=matrix(1,length(rtot),length(ctot)),tol=1e-05,maxit=500,verbose=TRUE)
+##
+##conditional maximisation on 2 dim
+##
+cm2<- function(rtot=NULL,ctot=NULL,m=matrix(1,length(rtot),length(ctot)),tol=1e-05,maxit=500,verbose=TRUE)
 {
   if(round(sum(rtot))!=round(sum(ctot))) 
     stop("row and column totals are not equal, ensure sum(rtot)==sum(ctot)")
