@@ -1,5 +1,7 @@
-cm3 <-
-function(rtot=NULL,ctot=NULL,m,tol=1e-05,maxit=500,verbose=FALSE)
+##
+##conditional maximization in 3 dimensions
+##
+cm3<-function(rtot=NULL,ctot=NULL,m,tol=1e-05,maxit=500,verbose=FALSE)
 {
   if(round(sum(rtot))!=round(sum(ctot)))
     stop("row and column totals are not equal, ensure sum(rtot)==sum(ctot)")
