@@ -1,9 +1,15 @@
-ffs <-
-function(P1,P2,d,b,m=NULL,method="stocks",b.mat=NULL,d.mat=NULL,b.deduct="native.gt0",...){
+##
+##flows from stock
+##
+#P1=P1;P2=P2;d=d;b=b.adj;m=m
+#P1 = s0; P2 = s1; d = df7$d; b = df7$b.adj; m = dm; method = "stocks"
+#method="stocks"; d.mat=NULL;b.mat=NULL;b.deduct="native.gt0"
+#m=NULL;
+ffs<-function(P1,P2,d,b,m=NULL,method="stocks",b.mat=NULL,d.mat=NULL,b.deduct="native.gt0",...){
   if(!(method %in% c("outside","stocks","deaths")) | length(method)!=1)
     stop("method must be one of outside, stocks or deaths")
   if(!(b.deduct %in% c("native.only","native.gt0")) | length(b.deduct)!=1)
-    stop("method must be one of di, stocks or deaths")
+    stop("method must be one of outside, stocks or deaths")
   R<-nrow(P1)
   #set up offset
   if(is.null(m)){
