@@ -1,5 +1,7 @@
-fm <-
-function(y){
+##
+##flow matrix
+##
+fm<-function(y){
   R<-dim(y)[3]
   dg<-diag(apply(y,c(1,2),sum))
   od<-apply(y,c(1,2),sum)
