@@ -1,5 +1,7 @@
-ipf2 <-
-function(rtot=NULL,ctot=NULL,m=matrix(1,length(rtot),length(ctot)),tol=1e-05,maxit=500,verbose=FALSE){
+##
+##ipf (rather than cm)...gives different estimates
+##
+ipf2<-function(rtot=NULL,ctot=NULL,m=matrix(1,length(rtot),length(ctot)),tol=1e-05,maxit=500,verbose=FALSE){
   if(!is.null(rtot) & !is.null(ctot))
     if(round(sum(rtot))!=round(sum(ctot))) 
       stop("row and column totals are not equal, ensure sum(rtot)==sum(ctot)")
