@@ -1,5 +1,7 @@
-ipf3 <-
-function(rtot=NULL,ctot=NULL,m=NULL,tol=1e-05,maxit=500,verbose=TRUE){
+##
+##ipf3
+##
+ipf3<-function(rtot=NULL,ctot=NULL,m=NULL,tol=1e-05,maxit=500,verbose=TRUE){
   if(any(round(colSums(rtot))!=round(rowSums(ctot))))
     stop("row and column totals are not equal for one or more sub-tables, ensure colSums(rtot)==rowSums(ctot)")
   n<-list(ik=rtot,
